@@ -24,19 +24,19 @@
 #include <tqwidgetstack.h>
 #include <tqpushbutton.h>
 
-#include <kapplication.h>
-#include <kaction.h>
+#include <tdeapplication.h>
+#include <tdeaction.h>
 #include <kcombobox.h>
-#include <kconfig.h>
-#include <kfiledialog.h>
-#include <kglobal.h>
+#include <tdeconfig.h>
+#include <tdefiledialog.h>
+#include <tdeglobal.h>
 #include <kiconloader.h>
 #include <kiconview.h>
-#include <klocale.h>
-#include <kmenubar.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemenubar.h>
+#include <tdemessagebox.h>
 #include <kstatusbar.h>
-#include <kstdaccel.h>
+#include <tdestdaccel.h>
 #include <kstdaction.h>
 #include <kstandarddirs.h>
 #include <kurlrequester.h>
@@ -59,7 +59,7 @@
 #include "kiosksync.h"
 
 KioskGui::KioskGui()
-    : KMainWindow( 0, "kioskgui" ), m_profileSelectionPage(0),
+    : TDEMainWindow( 0, "kioskgui" ), m_profileSelectionPage(0),
     m_componentSelectionPage(0), m_componentPage(0), m_profileAssignPage(0),
     m_profilePropsPage(0), m_data(0),
     m_activePage(0), m_profile(0), m_componentData(0)
@@ -72,7 +72,7 @@ KioskGui::KioskGui()
 
     updateBackground();
 
-    // tell the KMainWindow that this is indeed the main widget
+    // tell the TDEMainWindow that this is indeed the main widget
     setCentralWidget(m_view);
 
     setWidgetBackground(m_view);
@@ -91,7 +91,7 @@ KioskGui::KioskGui()
     connect(m_view->pbDiscard, TQT_SIGNAL(clicked()), this, TQT_SLOT(discardPage()));
     connect(m_view->pbFinished, TQT_SIGNAL(clicked()), this, TQT_SLOT(finishedPage()));
 
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup("General");
     m_profile = config->readEntry("CurrentProfile", "default");
     m_component = config->readEntry("CurrentComponent");
@@ -167,15 +167,15 @@ void KioskGui::setupActions()
 //    KStdAction::keyBindings(this, TQT_SLOT(optionsConfigureKeys()), actionCollection());
 //    KStdAction::configureToolbars(this, TQT_SLOT(optionsConfigureToolbars()), actionCollection());
     KStdAction::preferences(this, TQT_SLOT(slotConfig()), actionCollection());
-    m_uploadAction = new KAction(i18n("Upload &All Profiles"), TQString(), 0, this, TQT_SLOT(uploadAllProfiles()), actionCollection(), "upload_all");
-    m_backgroundAction = new KToggleAction(i18n("Background Graphics"), TQString(), 0, this, TQT_SLOT(slotUpdateBackground()), actionCollection(), "show_background");
+    m_uploadAction = new TDEAction(i18n("Upload &All Profiles"), TQString(), 0, this, TQT_SLOT(uploadAllProfiles()), actionCollection(), "upload_all");
+    m_backgroundAction = new TDEToggleAction(i18n("Background Graphics"), TQString(), 0, this, TQT_SLOT(slotUpdateBackground()), actionCollection(), "show_background");
 
     updateActions();
 }
 
 void KioskGui::updateActions()
 {
-   KConfig *config = kapp->config();
+   TDEConfig *config = kapp->config();
    config->setGroup("General");
    
    bool uploadEnabled = !config->readEntry("uploadURL").isEmpty();
@@ -184,14 +184,14 @@ void KioskGui::updateActions()
    m_backgroundAction->setChecked(config->readBoolEntry("FancyBackground", true));
 }
 
-void KioskGui::saveProperties(KConfig * /*config*/ )
+void KioskGui::saveProperties(TDEConfig * /*config*/ )
 {
     // the 'config' object points to the session managed
     // config file.  anything you write here will be available
     // later when this app is restored
 }
 
-void KioskGui::readProperties(KConfig * /*config*/ )
+void KioskGui::readProperties(TDEConfig * /*config*/ )
 {
     // the 'config' object points to the session managed
     // config file.  this function is automatically called whenever
@@ -235,7 +235,7 @@ void KioskGui::slotDeleteProfile(TQListViewItem *item)
     int result = KMessageBox::warningContinueCancel(this,
                i18n("<qt>You are about to delete the profile <b>%1</b>.<p>"
                     "Are you sure you want to do this?").arg(profile),
-               TQString(), KGuiItem(i18n("Delete"),"editdelete"));
+               TQString(), KGuiItem(i18n("Delete"),"edit-delete"));
     if (result == KMessageBox::Continue)
     {
        if (KioskRun::self()->deleteProfile(profile))
@@ -521,7 +521,7 @@ bool KioskGui::savePage(int page)
         m_profile = m_profileSelectionPage->listProfile->selectedItem() ?
                     m_profileSelectionPage->listProfile->selectedItem()->text(0) : TQString();
 
-        KConfig *config = kapp->config();
+        TDEConfig *config = kapp->config();
         config->setGroup("General");
         config->writeEntry("CurrentProfile", m_profile);
         config->sync();
@@ -630,7 +630,7 @@ bool KioskGui::queryClose()
     }
     if (m_uploadAction->isEnabled())
     {
-       KConfig *config = kapp->config();
+       TDEConfig *config = kapp->config();
        config->setGroup("General");
    
        KURL uploadUrl = config->readEntry("uploadURL");
@@ -647,7 +647,7 @@ bool KioskGui::queryClose()
 
 void KioskGui::uploadAllProfiles()
 {
-   KConfig *config = kapp->config();
+   TDEConfig *config = kapp->config();
    config->setGroup("General");
    TQString uploadPrefix = config->readEntry("uploadPrefix");
    TQString uploadURL = config->readEntry("uploadURL");
@@ -691,7 +691,7 @@ void KioskGui::uploadCurrentProfile()
 
 void KioskGui::slotUpdateBackground()
 {
-  KConfig *config = kapp->config();
+  TDEConfig *config = kapp->config();
   config->setGroup("General");
   config->writeEntry("FancyBackground", m_backgroundAction->isChecked());
   config->sync();
@@ -705,7 +705,7 @@ void KioskGui::updateBackground()
     m_view->setPaletteBackgroundPixmap(locate("appdata", "background.png"));
     m_view->logoLabel->setPixmap(locate("appdata", "logo.png"));
     m_view->logoLabel->setMinimumSize(TQSize(160,170));
-    TQString language = KGlobal::locale()->language();
+    TQString language = TDEGlobal::locale()->language();
     TQString caption = locate("appdata", "caption-"+language+".png");
     if (caption.isEmpty())
        caption = locate("appdata", "caption.png");
