@@ -29,12 +29,12 @@
 #include <tqdir.h>
 #include <tqfile.h>
 
-#include <kapplication.h>
-#include <kcmdlineargs.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdecmdlineargs.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kprocess.h>
 #include <ksavefile.h>
 #include <ksimpleconfig.h>
@@ -44,8 +44,8 @@
 
 #include "kiosksync.h"
 
-#include <kio/netaccess.h>
-#define NETACCESS	KIO::NetAccess
+#include <tdeio/netaccess.h>
+#define NETACCESS	TDEIO::NetAccess
 
 #undef DEBUG_ENTRIES
 
@@ -60,8 +60,8 @@ KioskRun::KioskRun( TQObject* parent, const char* name)
    m_saveConfigCache.setAutoDelete(true);
    m_immutableStatusCache.setAutoDelete(true);
    m_homeDir = TQDir::homeDirPath()+"/.trinity-test";
-   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-   m_kderc = TQFile::decodeName(args->getOption("kderc"));
+   TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
+   m_tderc = TQFile::decodeName(args->getOption("tderc"));
    m_isRoot = (getuid() == 0);
 }
 
@@ -104,7 +104,7 @@ KioskRun::setKdeDirs(const TQStringList &dirs)
    TQStringList xdgDataDirs = TQStringList::split(':', TQFile::decodeName(getenv("XDG_DATA_DIRS")));
    if (xdgDataDirs.isEmpty())
    {
-      xdgDataDirs = TQStringList::split(':', KGlobal::dirs()->kfsstnd_prefixes());
+      xdgDataDirs = TQStringList::split(':', TDEGlobal::dirs()->kfsstnd_prefixes());
       xdgDataDirs.pop_front();
       for(TQStringList::Iterator it = xdgDataDirs.begin();
           it != xdgDataDirs.end(); ++it)
@@ -127,7 +127,7 @@ KioskRun::setKdeDirs(const TQStringList &dirs)
    if (xdgConfigDirs.isEmpty())
    {
       xdgConfigDirs << "/etc/xdg";
-      TQString sysconfMenuDir = KGlobal::dirs()->findDirs("xdgconf-menu", TQString()).last();
+      TQString sysconfMenuDir = TDEGlobal::dirs()->findDirs("xdgconf-menu", TQString()).last();
       if (sysconfMenuDir.endsWith("/menus/"))
          xdgConfigDirs << sysconfMenuDir.left(sysconfMenuDir.length()-7);
       
@@ -153,26 +153,26 @@ KioskRun::deleteDir(const TQString &dir)
       return;
    Q_ASSERT(dir.startsWith(m_homeDir));
     
-   KProcess proc;
+   TDEProcess proc;
    proc << "rm" << "-rf" << dir;
-   proc.start(KProcess::Block);
+   proc.start(TDEProcess::Block);
 }
 
 void
-KioskRun::applyEnvironment(KProcess *p)
+KioskRun::applyEnvironment(TDEProcess *p)
 {
    p->setEnvironment("HOME", m_homeDir);
-   p->setEnvironment("KDEHOME", m_homeDir+"/.trinity");
-   p->setEnvironment("KDEROOTHOME", m_homeDir+"/.trinity");
-   p->setEnvironment("KDEDIRS", m_kdeDirs.join(":"));
+   p->setEnvironment("TDEHOME", m_homeDir+"/.trinity");
+   p->setEnvironment("TDEROOTHOME", m_homeDir+"/.trinity");
+   p->setEnvironment("TDEDIRS", m_kdeDirs.join(":"));
    p->setEnvironment("XDG_DATA_HOME", m_homeDir+"/.local/share");
    p->setEnvironment("XDG_DATA_DIRS", m_xdgDataDirs.join(":"));
    p->setEnvironment("XDG_CONFIG_HOME", m_homeDir+"/.config");
    p->setEnvironment("XDG_CONFIG_DIRS", m_xdgConfigDirs.join(":"));
    p->setEnvironment("DCOPAUTHORITY", m_homeDir+"/.trinity/DCOPserver");
-   p->setEnvironment("KDE_KIOSK_NO_PROFILES", "true");
+   p->setEnvironment("TDE_KIOSK_NO_PROFILES", "true");
    if (m_noRestrictions)
-      p->setEnvironment("KDE_KIOSK_NO_RESTRICTIONS", "true");
+      p->setEnvironment("TDE_KIOSK_NO_RESTRICTIONS", "true");
 }
 
 bool
@@ -192,26 +192,26 @@ void
 KioskRun::updateSycoca()
 {
    // Force update
-   TQString sycocaUpdateFile = KioskRun::self()->locateLocal("services", "update_ksycoca");
+   TQString sycocaUpdateFile = KioskRun::self()->locateLocal("services", "update_tdesycoca");
    TQFile file(sycocaUpdateFile);
    file.remove();
    file.open(IO_WriteOnly);
    file.close();
 
-   dcopRef("kded", "kbuildsycoca").call("recreate");
+   dcopRef("kded", "tdebuildsycoca").call("recreate");
 }
 
-KProcess*
+TDEProcess*
 KioskRun::run(const TQString &cmd, const TQStringList &args)
 {
-   KProcess *proc = new KProcess(this);
+   TDEProcess *proc = new TDEProcess(this);
    
    applyEnvironment(proc);
 
    *proc << cmd;
    *proc << args;
 
-   proc->start(KProcess::NotifyOnExit);
+   proc->start(TDEProcess::NotifyOnExit);
    return proc;
 }
 
@@ -248,9 +248,9 @@ KioskRun::setupConfigEnv()
 
    SetEnv home("HOME", m_homeDir);
    TQString kdeHome = m_homeDir+"/.trinity";
-   SetEnv kdehome("KDEHOME", kdeHome);
-   SetEnv kderoothome("KDEROOTHOME", kdeHome);
-   SetEnv kdedirs("KDEDIRS", m_kdeDirs.join(":"));
+   SetEnv tdehome("TDEHOME", kdeHome);
+   SetEnv tderoothome("TDEROOTHOME", kdeHome);
+   SetEnv tdedirs("TDEDIRS", m_kdeDirs.join(":"));
    SetEnv xdgDataHome("XDG_DATA_HOME", m_homeDir+"/.local/share");
    SetEnv xdgDataDirs("XDG_DATA_DIRS", m_xdgDataDirs.join(":"));
    SetEnv xdgConfigHome("XDG_CONFIG_HOME", m_homeDir+"/.config");
@@ -276,8 +276,8 @@ KioskRun::setupConfigEnv()
 
    m_configDir = TQString("%1/.trinity/share/config/").arg(m_homeDir);
 
-   m_instance = new KInstance("kioskrun");
-   (void) m_instance->dirs(); // Create KStandardDirs obj
+   m_instance = new TDEInstance("kioskrun");
+   (void) m_instance->dirs(); // Create TDEStandardDirs obj
 
    m_desktopPath = m_homeDir + "/Desktop/";
    m_desktopPath = m_instance->config()->readPathEntry( "Desktop", m_desktopPath);
@@ -286,13 +286,13 @@ KioskRun::setupConfigEnv()
       m_desktopPath.append('/');
    
    {
-      SetEnv kdehome("KDEHOME", "-");
-      SetEnv kderoothome("KDEROOTHOME", "-");
+      SetEnv tdehome("TDEHOME", "-");
+      SetEnv tderoothome("TDEROOTHOME", "-");
       SetEnv xdgDataHome("XDG_DATA_HOME", m_xdgDataDirs.first());
       SetEnv xdgConfigHome("XDG_CONFIG_HOME", m_xdgConfigDirs.first());
 
-      m_saveInstance = new KInstance("kioskrun");
-      (void) m_saveInstance->dirs(); // Create KStandardDirs obj
+      m_saveInstance = new TDEInstance("kioskrun");
+      (void) m_saveInstance->dirs(); // Create TDEStandardDirs obj
    }
 }
 
@@ -620,9 +620,9 @@ KioskRun::flushConfigCache()
 {
    while ( !m_saveConfigCache.isEmpty() )
    {
-      TQDictIterator<KConfig> it( m_saveConfigCache );
+      TQDictIterator<TDEConfig> it( m_saveConfigCache );
       TQString file = it.currentKey();
-      KConfig *config = it.current();
+      TDEConfig *config = it.current();
       bool dirty = config->isDirty();
       config->sync(); // Save
       if (!restoreImmutableStatus(file, dirty))
@@ -635,10 +635,10 @@ KioskRun::flushConfigCache()
    return true;
 }
 
-KConfig *
+TDEConfig *
 KioskRun::configFile(const TQString &filename)
 {
-   KConfig *config = m_saveConfigCache.find(filename);
+   TDEConfig *config = m_saveConfigCache.find(filename);
    if (config)
       return config;
 
@@ -656,10 +656,10 @@ KioskRun::configFile(const TQString &filename)
 void
 KioskRun::makeMutable(bool bMutable)
 {
-   KConfig *config = configFile("kdeglobals");
+   TDEConfig *config = configFile("kdeglobals");
    
    m_noRestrictions = bMutable;
-   if (KDE::version() < KDE_MAKE_VERSION(3,2,4))
+   if (KDE::version() < TDE_MAKE_VERSION(3,2,4))
    {
       config->setGroup("KDE Action Restrictions");
       if (bMutable)
@@ -672,9 +672,9 @@ KioskRun::makeMutable(bool bMutable)
          config->writeEntry("kiosk_exception", TQString());
       }
    }
-   // Propagate to kdeinit
-   dcopRef("klauncher", "klauncher").call("setLaunchEnv", 
-   	TQCString("KDE_KIOSK_NO_RESTRICTIONS"), TQCString(m_noRestrictions ? "true" : ""));
+   // Propagate to tdeinit
+   dcopRef("tdelauncher", "tdelauncher").call("setLaunchEnv", 
+   	TQCString("TDE_KIOSK_NO_RESTRICTIONS"), TQCString(m_noRestrictions ? "true" : ""));
    
    setConfigImmutable("kdeglobals", "KDE Action Restrictions", true);
 }
@@ -685,7 +685,7 @@ KioskRun::newConfigFiles()
    setupConfigEnv();
 
    TQStringList exceptions;
-   exceptions << "kconf_updaterc";
+   exceptions << "tdeconf_updaterc";
    
    TQStringList result;
    TQDir dir(m_configDir);
@@ -709,7 +709,7 @@ KioskRun::newConfigFiles()
 void
 KioskRun::mergeConfigFile(const TQString &filename)
 {
-   KConfig *saveCfg = configFile(filename);
+   TDEConfig *saveCfg = configFile(filename);
 
    kdDebug() << "KioskRun::mergeConfigFile(" << (m_configDir + filename) << ")" << endl;
    KSimpleConfig newCfg(m_configDir + filename);
@@ -724,7 +724,7 @@ KioskRun::mergeConfigFile(const TQString &filename)
           it2 != map.end(); ++it2)
       {
 #ifdef DEBUG_ENTRIES
-qWarning("[%s] %s --> %s", (*it).latin1(), it2.key().latin1(), it2.data().latin1());
+tqWarning("[%s] %s --> %s", (*it).latin1(), it2.key().latin1(), it2.data().latin1());
 #endif
          saveCfg->writeEntry(it2.key(), it2.data());
       }
@@ -746,9 +746,9 @@ KioskRun::setupRuntimeEnv()
    TQString cacheDir = TQString("%1/.trinity/cache-%2").arg(m_homeDir).arg(hostname);
 
    deleteDir(cacheDir);
-   KStandardDirs::makeDir(cacheDir);
+   TDEStandardDirs::makeDir(cacheDir);
    deleteDir(m_homeDir+"/.qt");
-   ::unlink(TQFile::encodeName(m_homeDir+".kderc"));
+   ::unlink(TQFile::encodeName(m_homeDir+".tderc"));
    
 
    TQString iceAuth = TQString("%1/.ICEauthority").arg(TQDir::homeDirPath());
@@ -759,15 +759,15 @@ KioskRun::setupRuntimeEnv()
 
    TQString dcopServerFile = m_homeDir+"/.trinity/DCOPserver";
 
-   KProcess kdeinit;
+   TDEProcess tdeinit;
    
-   applyEnvironment(&kdeinit);
+   applyEnvironment(&tdeinit);
    
-   kdeinit << "kdeinit";
+   tdeinit << "tdeinit";
    
-   connect(&kdeinit, TQT_SIGNAL(processExited(KProcess *)), &dlg, TQT_SLOT(slotFinished()));
+   connect(&tdeinit, TQT_SIGNAL(processExited(TDEProcess *)), &dlg, TQT_SLOT(slotFinished()));
    
-   kdeinit.start(KProcess::NotifyOnExit);
+   tdeinit.start(TDEProcess::NotifyOnExit);
 
    dlg.exec();
 
@@ -811,19 +811,19 @@ KioskRun::shutdownRuntimeEnv()
    delete m_dcopClient;
    m_dcopClient = 0;
    
-   KProcess kdeinit;
-   applyEnvironment(&kdeinit);
+   TDEProcess tdeinit;
+   applyEnvironment(&tdeinit);
    
-   kdeinit << "kdeinit_shutdown";
+   tdeinit << "tdeinit_shutdown";
    
-   kdeinit.start(KProcess::Block);
+   tdeinit.start(TDEProcess::Block);
 
-   KProcess dcopserver;
+   TDEProcess dcopserver;
    applyEnvironment(&dcopserver);
    
    dcopserver << "dcopserver_shutdown";
    
-   dcopserver.start(KProcess::Block);
+   dcopserver.start(TDEProcess::Block);
 }
 
 DCOPRef
@@ -840,7 +840,7 @@ KioskRun::dcopRef(const TQCString &appId, const TQCString &objId)
 bool
 KioskRun::lookupCustomAction(const TQString &action)
 {
-   KConfig *cfg = KioskRun::self()->configFile("kdeglobals");
+   TDEConfig *cfg = KioskRun::self()->configFile("kdeglobals");
    cfg->setGroup("KDE Custom Restrictions");
    return cfg->readBoolEntry(action, false);
 }
@@ -849,7 +849,7 @@ KioskRun::lookupCustomAction(const TQString &action)
 void
 KioskRun::setCustomAction(const TQString &action, bool checked)
 {
-   KConfig *cfg = KioskRun::self()->configFile("kdeglobals");
+   TDEConfig *cfg = KioskRun::self()->configFile("kdeglobals");
    cfg->setGroup("KDE Custom Restrictions");
    if (cfg->readBoolEntry(action, false) != checked)
    {
@@ -974,7 +974,7 @@ KioskRun::createRemoteDir(const KURL &dest)
          return true;
 
 #if KDE_IS_VERSION(3,2,91)
-      if (NETACCESS::lastError() == KIO::ERR_DIR_ALREADY_EXIST)
+      if (NETACCESS::lastError() == TDEIO::ERR_DIR_ALREADY_EXIST)
          return true;
 #endif
 
@@ -1141,7 +1141,7 @@ kdDebug() << "Moving " << src << " --> " << dest << endl;
 void
 KioskRun::getProfileInfo(const TQString &profile, TQString &description, TQString &installDir, TQString &installUser)
 {
-   KConfig *config = kapp->config();
+   TDEConfig *config = kapp->config();
 
    TQString defaultInstallDir = getProfilePrefix();
    if (defaultInstallDir.isEmpty())
@@ -1187,9 +1187,9 @@ KioskRun::openKderc()
       return m_localKdercConfig;
      
    KURL settingsUrl;
-   settingsUrl.setPath(m_kderc);
+   settingsUrl.setPath(m_tderc);
 
-   m_localKderc = ::locateLocal("tmp", "kderc_"+kapp->randomString(5));
+   m_localKderc = ::locateLocal("tmp", "tderc_"+kapp->randomString(5));
    ::unlink(TQFile::encodeName(m_localKderc));
 
    KURL localCopyUrl;
@@ -1235,7 +1235,7 @@ KioskRun::closeKderc()
 
    TQString saveUser = m_user;
    m_user = "root";
-   bool result = install(m_localKderc, m_kderc);
+   bool result = install(m_localKderc, m_tderc);
    m_localKderc = TQString();
    m_user = saveUser;
    kapp->config()->reparseConfiguration();
@@ -1329,7 +1329,7 @@ KioskRun::setProfileInfo(const TQString &profile, const TQString &description, c
    KUser thisUser;
    TQString newAdmin = thisUser.loginName()+":"; // This user, all hosts
 
-   KConfig *config = kapp->config();
+   TDEConfig *config = kapp->config();
 
    config->setGroup("Directories");
    TQString oldAdmin = config->readEntry("kioskAdmin");
@@ -1378,7 +1378,7 @@ KioskRun::deleteProfile(const TQString &profile, bool deleteFiles)
 TQString
 KioskRun::getProfilePrefix()
 {
-   KConfig *config = kapp->config();
+   TDEConfig *config = kapp->config();
       
    config->setGroup("Directories");
    
@@ -1417,7 +1417,7 @@ KioskRun::newProfile()
 {
    TQString profilePrefix = getProfilePrefix();
 
-   KConfig *config = kapp->config();
+   TDEConfig *config = kapp->config();
    for(int p = 1; p; p++)
    {
       TQString profile = TQString("profile%1").arg(p);
@@ -1440,7 +1440,7 @@ KioskRun::newProfile()
 TQStringList
 KioskRun::allProfiles()
 {
-   KConfig *config = kapp->config();
+   TDEConfig *config = kapp->config();
    TQStringList groups = config->groupList();
    TQStringList profiles;
    TQStringList directories;
@@ -1501,7 +1501,7 @@ KioskRun::getUserProfileMappings( ProfileMapping &groups, ProfileMapping &users,
    groups.clear();
    users.clear();
    
-   KConfig *config = kapp->config();
+   TDEConfig *config = kapp->config();
    config->setGroup("Directories");
    TQString mapFile = config->readEntry("userProfileMapFile");
    
@@ -1537,7 +1537,7 @@ KioskRun::getUserProfileMappings( ProfileMapping &groups, ProfileMapping &users,
 bool
 KioskRun::setUserProfileMappings( const ProfileMapping &groups, const ProfileMapping &users, const TQStringList &groupOrder)
 {
-   KConfig *config = kapp->config();
+   TDEConfig *config = kapp->config();
    config->setGroup("Directories");
    TQString mapFile = config->readEntry("userProfileMapFile");
    if (mapFile.isEmpty())
@@ -1589,10 +1589,10 @@ KioskRun::setUserProfileMappings( const ProfileMapping &groups, const ProfileMap
 void
 KioskRun::forceSycocaUpdate()
 {
-   // Touch $KDEDIR/share/services/update_ksycoca
+   // Touch $TDEDIR/share/services/update_tdesycoca
    KTempFile tempFile;
    tempFile.close();
-   TQString sycocaUpdateFile = locateSave("services", "update_ksycoca");
+   TQString sycocaUpdateFile = locateSave("services", "update_tdesycoca");
    remove(sycocaUpdateFile);
    install(tempFile.name(), sycocaUpdateFile);
 }
@@ -1608,7 +1608,7 @@ KioskRun::setCustomRestrictionFileBrowsing(bool restrict)
 {
    TQString file = "kdeglobals";
    TQString group = "KDE URL Restrictions";
-   KConfig *cfg = KioskRun::self()->configFile(file);
+   TDEConfig *cfg = KioskRun::self()->configFile(file);
    cfg->setGroup(group);
    int count = cfg->readNumEntry("rule_count");
    TQStringList urlRestrictions;
